//
//  ViewController.swift
//  Samples
//
//  Created by Фёдор Пашин on 06.02.2020.
//  Copyright © 2020 fedorpashin. All rights reserved.
//

import UIKit
import FloatingPanel

class ViewController: UIViewController, FloatingPanelControllerDelegate {

  let fpc = FloatingPanelController()

  @IBAction func buttonTapped(_ sender: Any) {
    fpc.delegate = self
    fpc.isRemovalInteractionEnabled = true
    let contentViewController = storyboard!.instantiateViewController(withIdentifier: "floatingPanelViewController")
    fpc.set(contentViewController: contentViewController)

    // Add the floating panel view to the controller's view on top of other views.
    self.view.addSubview(fpc.view)

    // REQUIRED. It makes the floating panel view have the same size as the controller's view.
    fpc.view.frame = self.view.bounds

    // In addition, Auto Layout constraints are highly recommended.
    // Constraint the fpc.view to all four edges of your controller's view.
    // It makes the layout more robust on trait collection change.
    fpc.view.translatesAutoresizingMaskIntoConstraints = false
    NSLayoutConstraint.activate([
      fpc.view.topAnchor.constraint(equalTo: self.view.topAnchor, constant: 0.0),
      fpc.view.leftAnchor.constraint(equalTo: self.view.leftAnchor, constant: 0.0),
      fpc.view.rightAnchor.constraint(equalTo: self.view.rightAnchor, constant: 0.0),
      fpc.view.bottomAnchor.constraint(equalTo: self.view.bottomAnchor, constant: 0.0),
    ])

    // Add the floating panel controller to the controller hierarchy.
    self.addChild(fpc)

    // Show the floating panel at the initial position defined in your `FloatingPanelLayout` object.
    fpc.show(animated: true) {
        // Inform the floating panel controller that the transition to the controller hierarchy has completed.
      self.fpc.didMove(toParent: self)
    }
  }

  func floatingPanelDidEndDraggingToRemove(_ vc: FloatingPanelController, withVelocity velocity: CGPoint) {
    // Inform the panel controller that it will be removed from the hierarchy.
    fpc.willMove(toParent: nil)

    // Hide the floating panel.
    fpc.hide(animated: true) {
        // Remove the floating panel view from your controller's view.
      self.fpc.view.removeFromSuperview()
        // Remove the floating panel controller from the controller hierarchy.
      self.fpc.removeFromParent()
    }
  }
}
